@@ -66,7 +66,9 @@ def to_python(xml):
     if (perspective_camera := xml.find("PerspectiveCamera")) is not None:
         viewpoint["perspective_camera"] = PerspectiveCamera.to_python(perspective_camera)
     if (orthogonal_camera := xml.find("OrthogonalCamera")) is not None:
-        viewpoint["orthogonal_camera"] = OrthogonalCamera.to_python(orthogonal_camera)
+        if xml.find("CameraViewPoint") is not None:
+            # BIM Track exports BCF 2.0 with half empty OrthogonalCamera when there is only a snapshot without camera viewpoint
+            viewpoint["orthogonal_camera"] = OrthogonalCamera.to_python(orthogonal_camera)
 
     if (lines := xml.find("Lines")) is not None:
         viewpoint["lines"] = [Line.to_python(line) for line in lines.findall("Line")]
